@@ -43,199 +43,89 @@ use Bootloader::Core;
 our @ISA = ('Bootloader::Core');
 use Bootloader::Path;
 
-#module interface
+sub GetOptions{
+  my $loader = shift;
 
+  my $arch = $loader->{"arch"};
 
-sub GetMetaData() {
-    my $loader = shift;
-   
-    # Options or entries respectively have types. Four types are defined:
-    #
-    # 	- boolean:           set or not set
-    # 	- string:            a string of characters which can be quoted if necessary
-    # 	- number:            a decimal number
-    # 	- filename:          a string interpreted as a filename
-    #
-    # 	
-    # The config file (/etc/elilo.conf) supports the following options:
-    # 
-    # Global options
-    # --------------
-    #
-    #     default=value       Name the default image to boot. If not defined ELILO
-    #                         will boot the first defined image.
-    #     timeout=number      The number of 10th of seconds to wait while in
-    #                         interactive mode before auto booting default kernel.
-    #                         Default is infinity.
-    #     delay=number        The number of 10th of seconds to wait before
-    #                         auto booting when not in interactive mode. 
-    #                         Default is 0.
-    #     prompt              Force interactive mode
-    #     verbose=number      Set level of verbosity [0-5]. Default 0 (no verbose)
-    #     root=filename       Set global root filesystem for Linux/ia64
-    #     read-only           Force root filesystem to be mounted read-only
-    #     append=string       Append a string of options to kernel command line
-    #     initrd=filename     Name of initrd file
-    #     image=filename      Define a new image
-    #     chooser=name        Specify kernel chooser to use: 'simple' or 'textmenu'.
-    #     message=filename    a message that is printed on the main screen if 
-    #                         supported by the chooser.
-    #     fX=filename         Some choosers may take advantage of this option to
-    #                         display the content of a file when a certain function
-    #                         key X is pressed. X can vary from 1-12 to cover 
-    #                         function keys F1 to F12.
-    #     noedd30             do not force the EDD30 EFI variable to TRUE when FALSE. 
-    #                         In other words, don't force the EDD30 mode if not set.
-    #
-    #
-    # Possible section types
-    # ----------------------
-    # 
-    #     image
-    #
-    #
-    # Image (section) options
-    # -----------------------
-    # 
-    #     root=filename       Set root filesystem for kernel
-    #     read-only           Force root filesystem to be mounted read-only
-    #     append=string       Append a string of options to kernel command line
-    #     initrd=filename     Name of initrd file
-    #     label=string        Logical name of image (used in interactive mode)
-    #     description=string  One line text description of the image.
-    #
-    #
-    # IA-64 specific global options
-    # -----------------------------
-    #
-    #     fpswa=file          Specify the filename for a specific FPSWA to load
-    #                         If this option is used no other file will be tried.
-    #     relocatable         In case of memory allocation error at initial
-    #                         load point of kernel, allow attempt to relocate 
-    #                         (assume kernels are relocatable).
-    #
-    # IA-64 specific image options
-    # ----------------------------
-    #
-    #     relocatable         In case of memory allocation error at initial
-    #                         load point of kernel, allow attempt to relocate 
-    #                         (assume this kernel is relocatable).
-    #
-    #
-    # IA-32 specific options
-    # ----------------------
-    #
-    #     legacy-free         Indicate that the host machine does not have a
-    #                         legacy BIOS at all.
-    #                         
-
-
-    my %exports;
-    
-    my @bootpart;
-    my @partinfo = @{$loader->{"partitions"} || []};
-    
-    # FIXME: boot from any partition (really?)
-    @bootpart = map {
-        my ($device, $disk, $nr, $fsid, $fstype, $part_type, $start_cyl, $size_cyl) = @$_;
-        $device;
-    } @partinfo;
-    
-    my $boot_partitions = join(":", @bootpart);
-    
-    my @md_arrays = keys %{$loader->{"md_arrays"} || {}};
-    my @root_part =  map {
-        my ($device, $disk, $nr, $fsid, $fstype, $part_type, $start_cyl, $size_cyl) = @$_;
-        # FIXME: weed out non-root partitions
-    } @partinfo;
-    my $root_devices = join(":",@root_part,\@md_arrays);
-    
-    my $arch = `uname --hardware-platform`;
-    chomp ($arch);
-
-
-    $exports{"global_options"} = {
-	default		=> "string:Default Boot Section:Linux",
-	timeout		=> "int:Timeout in 10th of Seconds:80:0:36000",
-	delay		=> "int:Delay to wait before Auto Booting in 10th of Seconds:0",
-	prompt		=> "bool:Show Boot Menu",
-	verbose		=> "int:Set Level of Verbosity [0-5]:0",
-	root		=> "path:Set global Root Filesystem:/",
-	"read-only"	=> "bool:Force rootfs to be mounted read-only",
-	append		=> "string:Append String of Options to Kernel Command Line:",
-	initrd		=> "path:Name of initrd File:/boot/initrd",
-	image		=> "path:Name of image File:/boot/vmlinuz",
-	chooser		=> "string:Specify Kernel Chooser to use:textmenu",
-	message		=> "string:Message printed on Main Screen (if supported):",
-	fX		=> "path:Display the Content of a File by Function Keys:",
-	noedd30		=> "bool:Don't force EDD30 Mode if not set:",
-	fpswa		=> "path:Specify the Filename for a specific FPSWA to load:",
+  my %exports;
+    $exports{"global"} = {
+	default		=> "",
+	timeout		=> "",
+	delay		=> "",
+	prompt		=> "bool",
+	verbose		=> "",
+	root		=> "",
+	"read-only"	=> "bool",
+	append		=> "",
+	initrd		=> "",
+	image		=> "",
+	chooser		=> "",
+	message		=> "",
+	fX		=> "",
+	noedd30		=> "bool",
+	fpswa		=> "",
 
 	# shadow entries for efi boot manager
-	boot_efilabel	=> "string:EFI Boot Manager Label::",
+	boot_efilabel	=> "",
 	#boot_rm_efilabel => "bool:Remove existing EFI Boot Manager Entries by Name:",
     };
 
     if ($arch eq "ia64") {
-      $exports{"global_options"}{"relocatable"} = "bool:Allow Attempt to relocate:";
+      $exports{"global_options"}{"relocatable"} = "bool";
     }
 
-    my $go = $exports{"global_options"};
-    
-    $exports{"section_options"} = {
-        type_image         => "bool:Image Section",
-	image_append       => "string:Optional Kernel Command Line Parameter",
-	image_description  => "string:One Line Text Description of the Image:",
-	image_image        => "path:Kernel Image:/boot/vmlinux",
-	image_initrd       => "path:Initial RAM Disk:/boot/initrd",
-	image_noverifyroot => "bool:Do not verify Filesystem before Booting:false",
-	image_readonly	   => "bool:Force Root Filesystem to be mounted read-only:",
-	image_root	   => "selectdevice:Root Device::" . $root_devices,
+    $exports{"section"} = {
+        type_image         => "",
+	image_append       => "",
+	image_description  => "",
+	image_image        => "",
+	image_initrd       => "",
+	image_noverifyroot => "bool",
+	"image_read-only"  => "bool",
+	image_root	   => "",
 
-	type_xen          => "bool:Xen section",
-	xen_xen => "select:Hypervisor:/boot/xen.gz:/boot/xen.gz",
-	xen_xen_append    => "string:Additional Xen Hypervisor Parameters:",
-	xen_image         => "path:Kernel image:/boot/vmlinux",
-	xen_root          => "select:Root device::" . $root_devices,
-	xen_append        => "string:Optional kernel command line parameter",
-	xen_initrd        => "path:Initial RAM disk:/boot/initrd",
+	type_xen          => "",
+	xen_xen => "",
+	xen_xen_append    => "",
+	xen_image         => "",
+	xen_root          => "",
+	xen_append        => "",
+	xen_initrd        => "",
     };
     if ($arch eq "ia64") {
-      $exports{"section_options"}{"image_relocatable"} = "bool:Allow Attempt to relocate:";
+      $exports{"section_options"}{"image_relocatable"} = "bool";
     }
 
-    my $so = $exports{"section_options"};
-
-    $loader->{"exports"}=\%exports;
-    return \%exports;
+    $loader->{"options"}=\%exports;
 }
 
-
 =item
 C<< $obj_ref = Bootloader::Core::ELILO->new (); >>
 
 Creates an instance of the Bootloader::Core::ELILO class.
+First argumetn is old configuration and second is architecture string like x86_64 or ia64
 
 =cut
 
 sub new {
     my $self = shift;
     my $old = shift;
+    my $arch = shift;
 
     my $loader = $self->SUPER::new ($old);
     $loader->{"default_global_lines"} = [
 	{ "key" => "timeout", "value" => 80 },
     ];
-    my $arch = `uname --hardware-platform`;
-    chomp ($arch);
     if ($arch eq "ia64")
     {
       my $line = { "key" => "relocatable",  "value" => "" };
       push  @{$loader->{"default_global_lines"}},  $line ;
     }
+    $loader->{"arch"} = $arch;
     bless ($loader);
 
-    $loader->GetMetaData();
+    $loader->GetOptions();
     $loader->l_milestone ("ELILO::new: Created ELILO instance");
     return $loader;
 }
@@ -309,40 +199,23 @@ sub ParseLines {
 	\@elilo_conf
     );
 
-    # handle global append information 
-    my $glob_app = undef;
     foreach my $opt_ref (@{$glob_ref->{"__lines"}|| []})
     {
         my $key = $opt_ref->{"key"};
         my $val = $opt_ref->{"value"};
         if ($key eq "append")
         {
-           $glob_app = $val;
-           $self->l_milestone("GLOBAL APPEND: $glob_app \n"); 
+           $self->l_milestone("ELILO::ParseLines - GLOBAL APPEND: $val \n"); 
         }
     }
 
 
     # handle section append information
     foreach my $sect_ref (@{$sect_ref} ) {
-        my $sect_app = undef;
-        my $sect_title = undef;
         foreach my $opt_ref (@{$sect_ref->{"__lines"}|| []})
         {
           my $key = $opt_ref->{"key"};
           my $val = $opt_ref->{"value"};
-          if($key eq "label") {
-            $sect_title = $val;
-#            print STDERR "label name: $val\n";
-          }
-          if ($key eq "append") {
-            $sect_app = $val;
-          }
-        }
-        if( defined $sect_app ) {
-#          print STDERR "SECTION $sect_title has APPEND: $sect_app \n";
-	} else {
-#          print STDERR "SECTION $sect_title has NO APPEND!\n";
         }
      }
 
@@ -397,16 +270,6 @@ ParseLines on success, or undef on fail.
 sub CreateLines {
     my $self = shift;
 
-    # FIXME: think this is unnecessary code, no one else needs it, please check
-    if ($self->{"global"}{"__modified"} || 0) {
-	my @lines = @{$self->{"global"}{"__lines"} || []};
-	my @out_lines = ();
-	foreach my $line_ref (@lines) {
-	    push @out_lines, $line_ref;
-	}
-	$self->{"global"}{"__lines"} = \@out_lines;
-    }
-
     # create /etc/elilo.conf lines
     my $elilo_conf = $self->PrepareMenuFileLines (
 	$self->{"sections"},
@@ -444,25 +307,18 @@ sub Global2Info {
     my $self = shift;
     my @lines = @{+shift};
     my @sections = @{+shift};
-    my $go = $self->{"exports"}{"global_options"};
-
-    # FIXME: Do we need the arch stuff???
-    #my $arch = $self->{"exports"}{"arch"};
+    my $go = $self->{"options"}{"global"};
 
     my %ret = ();
 
     foreach my $line_ref (@lines) {
 	my $key = $line_ref->{"key"};
 	my $val = $line_ref->{"value"};
-	my ($type) = split /:/, $go->{$key};
+	my $type = $go->{$key};
 
-	#if ($key eq "boot")
-	#{
-	#    $key = boot2special($val, $arch);
-	#    $ret{$key} = $val if defined $key;
-	#}
-	#elsif ($type eq "bool") {
-	if ($type eq "bool") {
+        $val = int($val/10) if ($key eq "timeout");
+
+	if (defined $type && $type eq "bool") {
 	    $ret{$key} = "true";
 	}
 	else {
@@ -491,12 +347,9 @@ sub Info2Global {
 
     my @lines = @{$globinfo{"__lines"} || []};
     my @lines_new = ();
-    my $go = $self->{"exports"}{"global_options"};
+    my $go = $self->{"options"}{"global"};
     $globinfo{"default"} = $sections[0]->{"name"} unless (defined $globinfo{"default"});
 
-    # FIXME: Do we need the arch stuff???
-    #my $arch = $self->{"exports"}{"arch"};
-
     # allow to keep the section unchanged
     return \@lines unless $globinfo{"__modified"} || 0;
 
@@ -509,28 +362,21 @@ sub Info2Global {
 	my $key = $line_ref->{"key"};
 
 	# only accept known global options :-)
-	next unless exists $go->{$key};
+	unless (exists $go->{$key})
+        {
+	    $self->l_milestone (
+		"ELILO::Info2Global: Ignoring key '$key' for global section");
+            next;
+        }
 
-	#if ($key eq "boot"){
-	#    my $special = boot2special($line_ref->{"value"}, $arch);
-	#
-	#    if ( exists ($globinfo{$special}) ) {
-	#	if ( defined ($globinfo{$special})) {
-	#	    $line_ref->{"value"} = $globinfo{$special};
-	#	}		
-	#	delete $globinfo{$special};
-	#    }
-	#}
-	#else {
-	    if (defined ($globinfo{$key})) {
-		$line_ref->{"value"} = delete $globinfo{$key};
-	    }
-	    else {
-		next;
-	    }
-	#}
+        if (defined ($globinfo{$key})) {
+            $line_ref->{"value"} = delete $globinfo{$key};
+            $line_ref->{"value"} = $line_ref->{"value"}*10 if ($key eq "timeout");
+	}else {
+	    next;
+	}
 
-	my ($type) = split /:/, $go->{$key};
+	my $type = $go->{$key};
 	# bool values appear in a config file or not. there might be types
 	# like 'yesno' or 'truefalse' in the future which behave differently
 	if ($type eq "bool") {
@@ -538,7 +384,7 @@ sub Info2Global {
 	    $line_ref->{"value"} = "";
 	}
 
-	push @lines_new, $line_ref if defined $line_ref;
+	push @lines_new, $line_ref;
     };
 
     @lines = @lines_new;
@@ -547,27 +393,20 @@ sub Info2Global {
     while ((my $key, my $value) = each (%globinfo)) {
 	# only accept known global options :-)
 	next unless exists $go->{$key};
-	#next if $key =~ /^__/;
+        $value = $value*10 if ($key eq "timeout");
 
-	if ($key eq "boot_slot") {
-		push @lines, {
-		    "key" => "boot",
-		    "value" => $value,
-		}
-	}
-	else {
-	    my ($type) = split /:/, $go->{$key};
-	    # bool values appear in a config file or not
-	    if ($type eq "bool") {
-		next if $value ne "true";
-		$value = "";
-	    }
+        my ($type) = split /:/, $go->{$key};
+	# bool values appear in a config file or not
+	if ($type eq "bool") {
+            next if $value ne "true";
+            $value = "";
+        }
 
-	    push @lines, {
-		"key" => $key,
-		"value" => $value,
-	    };
-	}
+        push @lines, {
+            "key" => $key,
+            "value" => $value,
+        };
+	
     }
     return \@lines;
 }
@@ -591,7 +430,7 @@ sub Info2Section {
 
     my @lines = @{$sectinfo{"__lines"} || []};
     my $type = $sectinfo{"type"} || "";
-    my $so = $self->{"exports"}{"section_options"};
+    my $so = $self->{"options"}{"section"};
     my @lines_new = ();
 
     # allow to keep the section unchanged
@@ -606,11 +445,7 @@ sub Info2Section {
 
     foreach my $line_ref (@lines) {
 	my $key = $line_ref->{"key"};
-
-        if ($key eq "vmm")
-        {
-          $key = "xen";
-        }
+        $key = "xen" if ($key eq "vmm"); #standartize xen key
 
 	if ($key eq "label")
 	{
@@ -645,7 +480,7 @@ sub Info2Section {
 
 	    $line_ref->{"value"} = $sectinfo{$key};
 	    delete ($sectinfo{$key});
-	    my ($stype) = split /:/, $so->{$type . "_" . $key};
+	    my $stype = $so->{$type . "_" . $key};
 	    # bool values appear in a config file or not
 	    if ($stype eq "bool") {
 	        next if $line_ref->{"value"} ne "true";
@@ -653,6 +488,7 @@ sub Info2Section {
 	    }
 	}
 
+        #FIXME is if needed?
 	push @lines_new, $line_ref if defined $line_ref;
     }
 
@@ -741,7 +577,7 @@ information about the section.
 sub Section2Info {
     my $self = shift;
     my @lines = @{+shift};
-    my $so = $self->{"exports"}{"section_options"};
+    my $so = $self->{"options"}{"section"};
 
     my %ret = ();
 
@@ -751,7 +587,7 @@ sub Section2Info {
 
 	if ($key eq "label")
 	{
-	    my $on = $self->Comment2OriginalName ($line_ref->{"comment_before"});
+	    my $on = $self->Comment2OriginalName (\%ret,$line_ref->{"comment_before"});
 	    $ret{"original_name"} = $on if ($on ne "");
 	    $ret{"name"} = $val;
 	    next;
@@ -783,7 +619,7 @@ sub Section2Info {
            }
            else
            {
-             $ret{"append"} = $val if $val ne "";
+             $ret{"append"} = $val;
            }
            next;
         }
@@ -796,8 +632,9 @@ sub Section2Info {
 	    next; 
 	}
 	
-	my ($type) = split /:/, $so->{$ret{"type"} . "_" . $key};
-	if ($type eq "bool") {
+	my ($type) = $so->{$ret{"type"} . "_" . $key};
+	if ($type eq "bool")
+        {
 	    $val = "true";
 	}
 	$ret{$key} = $val;
