@@ -49,8 +49,6 @@ C<< $settings_ref = Bootloader::Library->GetSettings (); >>
 
 C<< $status Bootloader::Library->SetSettings ($settings_ref); >>
 
-C<< $meta_ref = Bootloader::Library->GetMetaData (); >>
-
 C<< $global_ref = Bootloader::Library->GetGlobalSettings (); >>
 
 C<< $status = Bootloader::Library->SetGlobalSettings ($global_settings_ref); >>
@@ -82,14 +80,8 @@ use strict;
 
 use Bootloader::Core;
 use Bootloader::MBRTools;
+use Bootloader::Logger;
 
-# this is bad style, load modules when required
-use Bootloader::Core::GRUB;
-use Bootloader::Core::LILO;
-use Bootloader::Core::ELILO;
-use Bootloader::Core::ZIPL;
-use Bootloader::Core::PowerLILO;
-use Bootloader::Core::NONE;
 
 =item
 C<< $obj_ref = Bootloader::Library->new (); >>
@@ -107,9 +99,8 @@ sub new {
 
 sub GetLogRecords {
     my $self = shift;
-
-    my $loader = $self->{"loader"};
-    return defined $loader ? $loader->GetLogRecords () : undef;
+  
+    return Bootloader::Logger::instance()->GetLogRecords();
 }
 
 =item
@@ -132,41 +123,59 @@ EXAMPLE:
 sub SetLoaderType {
     my $self = shift;
     my $bootloader = shift;
+    my $arch = shift;
 
     my $loader = exists $self->{"loader"} ? $self->{"loader"} : undef;
 
     if ($bootloader eq "grub")
     {
+        require Bootloader::Core::GRUB;
 	$loader = Bootloader::Core::GRUB->new ($loader);
     }
     elsif ($bootloader eq "lilo")
     {
+        require Bootloader::Core::LILO;
 	$loader = Bootloader::Core::LILO->new ($loader);
     }
     elsif ($bootloader eq "elilo")
     {
-        $loader = Bootloader::Core::ELILO->new ($loader);
+        require Bootloader::Core::ELILO;
+        unless (defined $arch)
+        {
+          Bootloader::Logger::instance()->warning("Bootloader::Library::SetLoaderType: Missing arch for elilo.");
+          $arch = "ia64";
+        }
+        $loader = Bootloader::Core::ELILO->new ($loader,$arch);
     }
     elsif ($bootloader eq "zipl")
     {
+        require Bootloader::Core::ZIPL;
         $loader = Bootloader::Core::ZIPL->new ($loader);
     }
     elsif ($bootloader eq "ppc")
     {
-	$loader = Bootloader::Core::PowerLILO->new ($loader);
+        require Bootloader::Core::PowerLILO;
+        unless (defined $arch)
+        {
+          Bootloader::Logger::instance()->warning("Bootloader::Library::SetLoaderType: Missing subarch for powerlilo.");
+          $arch = "chrp";
+        }
+	$loader = Bootloader::Core::PowerLILO->new ($loader,$arch);
     }
     elsif ($bootloader eq "none")
     {
+        require Bootloader::Core::NONE;
 	$loader = Bootloader::Core::NONE->new ($loader);
     }
     else
     {
+        require Bootloader::Core::NONE;
 	$loader = Bootloader::Core::NONE->new ($loader);
-	$loader->l_error ("Bootloader::Library::SetLoaderType: Initializing for unknown bootloader $bootloader, fallback to none");
+        Bootloader::Logger::instance()->error("Bootloader::Library::SetLoaderType: Initializing for unknown bootloader $bootloader, fallback to none");
     }
 
     $self->{"loader"} = $loader;
-    $loader->l_milestone ("Bootloader::Library::SetLoaderType: TRACE new $bootloader");
+    Bootloader::Logger::instance()->milestone ("Bootloader::Library::SetLoaderType: TRACE new $bootloader");
     return 1;
 }
 
@@ -198,7 +207,7 @@ sub DefineMountPoints {
 
     while ((my $mp, my $dev) = each (%{$mountpoints_ref}))
     {
-	$loader->l_milestone ("Library::DefineMountPoints: Mount point: $mp ; Device: $dev");
+	Bootloader::Logger::instance()->milestone ("Library::DefineMountPoints: Mount point: $mp ; Device: $dev");
     }
     $loader->{"mountpoints"} = $mountpoints_ref;
     return 1;
@@ -208,7 +217,7 @@ sub GetMountPoints {
     my $self = shift;
 
     my $loader = $self->{"loader"};
-    $loader->l_milestone ("Library::GetMountPoints: TRACE");
+    Bootloader::Logger::instance()->milestone ("Library::GetMountPoints: TRACE");
     return $loader->{"mountpoints"};
 }
 
@@ -242,7 +251,7 @@ sub DefinePartitions {
     foreach my $part_ref (@{$partitions_ref})
     {
 	my ($part, $disk, $num, @part_info ) = @{$part_ref};
-	$loader->l_milestone ("Library::DefinePartitions: Partition: $part ; " .
+	Bootloader::Logger::instance()->milestone ("Library::DefinePartitions: Partition: $part ; " .
 			  "Disk: $disk ; Number: $num ; Info: " .
 			  join(", ", map { "$_"; } @part_info) );
     }
@@ -283,7 +292,7 @@ sub DefineMDArrays {
     while ((my $md, my $members_ref) = each (%{$md_arrays_ref}))
     {
 	my $members = join ", ", @{$members_ref};
-	$loader->l_milestone ("Library::DefineMDArrays: MD Array: $md ; Members: $members");
+	Bootloader::Logger::instance()->milestone ("Library::DefineMDArrays: MD Array: $md ; Members: $members");
     }
     $loader->{"md_arrays"} = $md_arrays_ref;
     return 1;
@@ -318,12 +327,46 @@ sub DefineMultipath {
 
     while ((my $phys, my $mp) = each (%{$mp_ref}))
     {
-	$loader->l_milestone ("Library::DefineMultipath: Real device: $phys ;  multipath $mp");
+	Bootloader::Logger::instance()->milestone ("Library::DefineMultipath: Real device: $phys ;  multipath $mp");
     }
     $loader->{"multipath"} = $mp_ref;
     return 1;
 }
 
+=item
+C<< $status = Bootloader::Library->DefineMultipath (\%multipath); >>
+
+Define udev mapping of devices.
+We only need information for GRUB to translate udev device to kernel and then to grub device.
+
+As parameter, it takes a reference to a map of all udev names to correspond kernel names.
+Returns undef on fail, defined nonzero value otherwise.
+
+EXAMPLE:
+
+  my $mp = {
+    "/dev/disks/by-id/longhorribleid" => "/dev/sda",
+    "/dev/disks/by-id/longhorribleid-part1" => "/dev/sda1",
+  };
+  Bootloader::Library->DefineUdevMapping ($mp);
+
+=cut
+
+sub DefineUdevMapping($) {
+    my $self = shift;
+    my $map_ref = shift;
+
+    my $loader = $self->{"loader"};
+    return undef unless defined $loader;
+
+    while ((my $phys, my $mp) = each (%{$map_ref}))
+    {
+	Bootloader::Logger::instance()->milestone ("Library::DefineUdevMapping: Udev device: ".($phys||"")." ;  kernel: ".($mp||"")."");
+    }
+
+  $loader->{"udevmap"} = $map_ref;
+  return 1;
+}
 =item
 C<< $status = Bootloader::Library->ReadSettings (); >>
 
@@ -347,7 +390,7 @@ sub ReadSettings {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone( "Library::ReadSettings: TRACE" );
+    Bootloader::Logger::instance()->milestone( "Library::ReadSettings: TRACE" );
     my $files_ref = $loader->ReadFiles ($loader->ListFiles ());
     if (! defined ($files_ref))
     {
@@ -379,13 +422,10 @@ sub WriteSettings {
     my $self = shift;
     my $menu_only = shift;
 
-# FIXME remove this line after proper testing
-# $menu_only = 0;
-
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone(" Library::WriteSettings: TRACE menu_only:". ($menu_only ||""));
+    Bootloader::Logger::instance()->milestone(" Library::WriteSettings: TRACE menu_only:". ($menu_only || "undefined"));
     $loader->{"resolve_symlinks"} = 1;
     my $new_lines_ref = $loader->CreateLines ();
     if (! defined ($new_lines_ref))
@@ -418,7 +458,7 @@ sub ReadSettingsTmp {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone(" Library::ReadSettingsTmp: TRACE tmp_dir $tmp_dir ");
+    Bootloader::Logger::instance()->milestone(" Library::ReadSettingsTmp: TRACE tmp_dir $tmp_dir ");
 
     my @files = @{$loader->ListFiles ()};
     my %filenames = ();
@@ -466,7 +506,7 @@ sub WriteSettingsTmp {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone(" Library::WriteSettingsTmp: TRACE tmp_dir $tmp_dir ");
+    Bootloader::Logger::instance()->milestone(" Library::WriteSettingsTmp: TRACE tmp_dir $tmp_dir ");
 
     my $new_lines_ref = $loader->CreateLines ();
     if (! defined ($new_lines_ref))
@@ -510,14 +550,14 @@ sub GetFilesContents {
     if (! defined $loader or $loader eq "none") {
 	return undef;
     }
-
-    $loader->l_milestone(" Library::GetFilesContents TRACE ");
+    my $logger = Bootloader::Logger::instance();
+    $logger->milestone(" Library::GetFilesContents TRACE ");
 
     $loader->{"resolve_symlinks"} = 0;
     my $new_lines_ref = $loader->CreateLines ();
     if (! defined ($new_lines_ref))
     {
-	$loader->l_error ("Library::GetFileContents: Error while getting files contents occurred");
+	$logger->error ("Library::GetFileContents: Error while getting files contents occurred");
 	return undef;
     }
     my %files = ();
@@ -544,7 +584,7 @@ sub SetFilesContents {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone(" Library::SetFilesContents TRACE ");
+    Bootloader::Logger::instance()->milestone(" Library::SetFilesContents TRACE ");
 
     my %lines = ();
     while ((my $fn, my $contents) = each (%{$files_ref}))
@@ -582,7 +622,7 @@ sub UpdateBootloader {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone("Library::UpdateBootloader: TRACE avoid_init $avoid_init");
+    Bootloader::Logger::instance()->milestone("Library::UpdateBootloader: TRACE avoid_init ".($avoid_init||""));
 
     return $loader->UpdateBootloader ($avoid_init);
 }
@@ -598,7 +638,7 @@ EXAMPLE:
   my $status = Bootloader::Library->InitializeBootloader ();
   if (! defined ($status))
   {
-    die "Connot initialize the bootloader";
+    die "Cannot initialize the bootloader";
   }
 
 =cut
@@ -609,7 +649,7 @@ sub InitializeBootloader {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone( "Library::InitializeBootloader: TRACE");
+    Bootloader::Logger::instance()->milestone( "Library::InitializeBootloader: TRACE");
 
     return $loader->InitializeBootloader ();
 }
@@ -640,7 +680,7 @@ sub ListConfigurationFiles {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone( "Library::ListConfigurationFiles TRACE");
+    Bootloader::Logger::instance()->milestone( "Library::ListConfigurationFiles TRACE");
 
     return $loader->ListFiles ();
 }
@@ -663,7 +703,7 @@ sub GetSettings {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone( "Library::GetSettings TRACE");
+    Bootloader::Logger::instance()->milestone( "Library::GetSettings TRACE");
     return $loader->GetSettings ();
 }
 
@@ -686,7 +726,7 @@ sub SetSettings {
     my $loader = $self->{"loader"};
     return undef unless defined $loader;
 
-    $loader->l_milestone( "Library::SetSettings TRACE");
+    Bootloader::Logger::instance()->milestone( "Library::SetSettings TRACE");
 
     return $loader->SetSettings ($settings_ref);
 }
@@ -725,24 +765,6 @@ sub GetSections {
     return $settings_ref->{"sections"};
 }
 
-=item
-C<< $meta_ref = Bootloader::Library->GetMetaData (); >>
-
-Gets the meta data of the bootloader describing possible setting in the config,
-its data type, default value, etc.
-Returns undef on fail.
-
-=cut
-
-sub GetMetaData {
-    my $self = shift;
-    my $loader = $self->{loader} || return undef;
-
-    $loader->l_milestone( "Library::GetMetaData TRACE");
-
-    return $loader->GetMetaData();;
-}
-
 =item
 C<< $global_ref = Bootloader::Library->GetGlobalSettings (); >>
 
@@ -918,13 +940,37 @@ sub GrubDev2UnixDev {
     my $grub_dev = shift;
     my $loader = $self->{loader} || return undef;
 
-    $loader->l_milestone( "Library::GrubDev2UnixDev grub_dev: $grub_dev" );
+    Bootloader::Logger::instance()->milestone( "Library::GrubDev2UnixDev grub_dev: $grub_dev" );
 
     my $unix_dev = $loader->GrubDev2UnixDev ($grub_dev);
 
     return $unix_dev;
 }
 
+=item
+C<< ($dev,$path) = Bootloader::Library->SplitPath ($path); >>
+
+Split unix path to device and relative path on this device.
+
+=cut
+
+# (string,string) SplitPath (string path)
+sub SplitPath {
+    my $self = shift;
+    my $opath = shift;
+    my $loader = $self->{loader} || return undef;
+
+    my @ret = $loader->SplitDevPath ($opath);
+
+    if (scalar (@ret) == 2){
+        Bootloader::Logger::instance()->milestone( "Library::SplitPath arg:: $opath result dev: ".($ret[0]||"")." result path: ".($ret[1]||"") );
+    }else{
+        Bootloader::Logger::instance()->milestone( "Library::SplitPath arg:: $opath result undef");
+    }
+
+    return @ret;
+}
+
 =item
 C<< $result = Bootloader::Library::DetectThinkpadMBR ($disk); >>
 
@@ -936,9 +982,8 @@ Try detect on disk if contains ThinkpadMBR. Return true if detected.
 sub DetectThinkpadMBR {
   my $self = shift;
   my $disk = shift;
-  my $res = MBRTools::IsThinkpadMBR($disk);
-  $self->{"loader"}->l_milestone("Library::DetectThinkpadMBR on $disk result $res" )
-      if (defined $self->{"loader"});
+  my $res = Bootloader::MBRTools::IsThinkpadMBR($disk);
+  Bootloader::Logger::instance()->milestone("Library::DetectThinkpadMBR on $disk result $res" );
   return $res;
 }
 
@@ -953,23 +998,46 @@ Write generic mbr to disk on thinkpad. Return undef if fail.
 sub WriteThinkpadMBR {
    my $self = shift;
    my $disk = shift;
-   my $res = MBRTools::PatchThinkpadMBR($disk);
-   $self->{"loader"}->l_milestone("Library::WriteThinkpadMBR on $disk result $res" ) 
-         if (defined $self->{"loader"});
+   my $res = Bootloader::MBRTools::PatchThinkpadMBR($disk);
+   Bootloader::Logger::instance()->milestone("Library::WriteThinkpadMBR on $disk result $res" );
    return $res;
 }
 
+=item
+C<< $result = Bootloader::Library::ExamineMBR ($disk); >>
+
+Detects what code is in MBR of device. Return string or undef if fail.
+Possible string is:
+  generic -> generic MBR
+  grub -> Grub MBR
+  lilo -> lilo stage1
+  windows -> windows
+  vista -> windows vista (has another mbr)
+  thinkpad -> thinkpad custom mbr
+  unknown -> unknown code
+  invalid -> code which cannot boot
+
+=cut
+
+#  ExamineMBR (string disk)
+sub ExamineMBR($){
+  my $self = shift;
+  my $disk = shift;
+  my $res = Bootloader::MBRTools::examineMBR($disk);
+  Bootloader::Logger::instance()->milestone("Library::ExamineMBR on $disk result ".($res||"nil"));
+  
+  return $res;
+}
+
 sub CountGRUBPassword{
   my $self = shift;
   my $pass = shift;
   my $res = qx{echo "md5crypt \
   $pass" | grub --batch | grep Encrypted };
   $res =~ s/Encrypted:\s+(.*)$/$1/;
-  $self->{"loader"}->l_milestone("Library::CountGRUBPassword result $res" )
-      if (defined $self->{"loader"});
+  Bootloader::Logger::instance()->milestone("Library::CountGRUBPassword result $res" );
   return undef unless $res =~ m/^\$1\$.*\$.*$/;
   return $res;
-
 }
 
 sub UpdateSerialConsole{
@@ -978,18 +1046,14 @@ sub UpdateSerialConsole{
   my $console = shift;
   my $ret = $append;
 
-
-  if ($console ne "") {
-    $console = "console=$console";
-    if ($ret =~ m/console=ttyS(\d+)(,(\w+))?/){
-      $ret =~ s/console=ttyS(\d+)(,(\w+))?/$console/ ;
-    } else {
-      $ret = "$append $console";
-    }
+  $console = "console=$console" unless ($console eq "");
+  if ($ret =~ m/console=ttyS(\d+)(,(\w+))?/){
+    $ret =~ s/console=ttyS(\d+)(,(\w+))?/$console/ ;
+  } elsif ($console ne ""){
+    $ret = "$append $console";
   }
 
-  $self->{"loader"}->l_milestone("Library::UpdateSerialConsole append $append console $console res $ret" )
-     if (defined $self->{"loader"});
+  Bootloader::Logger::instance()->milestone("Library::UpdateSerialConsole append $append console $console res $ret" );
 
   return $ret;
 }
